Name:		ola
Version:	0.10.3
Release:	1%{?dist}
Summary:	Open Lighting Architecture
License:	GPLv2 and LGPLv2
URL:		https://github.com/OpenLightingProject/ola
Source:		https://github.com/OpenLightingProject/ola/archive/%{version}.tar.gz

# readdir_r is deprecated
# issue: https://github.com/OpenLightingProject/ola/issues/1055
# temporary fix PR: https://github.com/OpenLightingProject/ola/pull/1167
Patch0:		ola.readdir.patch

# Compilers/Generators/Tools
BuildRequires:	gcc-c++
BuildRequires:	libtool
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	protobuf-compiler
BuildRequires:	pkgconfig
# Java
BuildRequires:	maven-local
BuildRequires:	java-devel
BuildRequires:	mvn(com.google.protobuf:protobuf-java)
# Libraries
BuildRequires:	pkgconfig(cppunit)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(avahi-client)
BuildRequires:	pkgconfig(libusb-1.0) >= 1.0.2
BuildRequires:	pkgconfig(libmicrohttpd) >= 0.4.0
BuildRequires:	pkgconfig(libudev)
BuildRequires:	pkgconfig(protobuf) >= 0.2
BuildRequires:  pkgconfig(liblo)
BuildRequires:	openslp-devel
# Python libraries
BuildRequires:  python2-devel
BuildRequires:	protobuf-python
BuildRequires:	numpy
# noarch data files (js,html,css, etc.)
Requires:	%{name}-data = %{version}-%{release}

%description
The Open Lighting Architecture is a framework for lighting control information.
It supports a range of protocols and over a dozen USB devices. It can run as a
standalone service, which is useful for converting signals between protocols,
or alternatively using the OLA API, it can be used as the back-end for lighting
control software. OLA runs on many different platforms including ARM, which
makes it a perfect fit for low cost Ethernet to DMX gateways.

%package devel
Requires:	%{name}%{?_isa} = %{version}-%{release}
Group:		Development/Libraries
Summary:	C/C++ Development files for OLA

%description devel
The OLA C/C++ library


%package -n python2-%{name}
Requires:	%{name} = %{version}-%{release}
Requires:	protobuf-python
Requires:	numpy
Group:		Development/Libraries
Summary:	Python Development files for OLA
BuildArch:	noarch
%{?python_provide:%python_provide python2-%{name}}

%description -n python2-%{name}
The OLA python library

%package rdm-tests
Requires:	%{name} = %{version}-%{release}
Requires:       python2-%{name} = %{version}-%{release}
Group:		Development/Libraries
BuildArch:	noarch
Summary:	RDM test suite using OLA and python
Provides:	bundled(jquery) = 1.7.2, bundled(jquery-ui) = 1.8.21

%description rdm-tests
The rdm test suite for OLA

%package data
Group:		Development/Libraries
BuildArch:	noarch
Summary:	Data for OLA
Provides:	bundled(bootstrap) = 3.3.2, bundled(jquery) = 2.1.3
Provides:	bundled(angularjs) = 1.3.14, bundled(angular-route) = 1.3.14

%description data
HTML, CSS, JS and RDM PIDs files for OLA

%package ja-rule
Requires:	%{name}%{?_isa} = %{version}-%{release}
Summary:	Tools for DMX/RDM devices

%description ja-rule
Tools to update and configure your ja-rule devices (experimental)

%package java-client
Summary:	Java library for ola
BuildArch:	noarch

%description java-client
Experimental java library for interfacing with ola

%package java-client-javadoc
Summary:	Javadoc for %{name}-java-client
BuildArch:	noarch

%description java-client-javadoc
This package contains the API documentation for %{name}-java-client.


%prep
%setup -q -n %{name}-%{version}
%patch0 -p1


%build
autoreconf -i
%configure \
	--enable-rdm-tests \
	--enable-python-libs \
	--enable-shared \
	--enable-ja-rule \
	--disable-static
#only link as needed
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool
#rpath, please die
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
#we can't fix this upstream (I think)
sed -i "s|\$(LN_S) -f \$(bindir)\/|\$(LN_S) -f |g" Makefile
%make_build
#Java Part
cd java
make src/main/java/ola/proto/Ola.java
make src/main/java/ola/rpc/Rpc.java
%mvn_build

%check
export LD_LIBRARY_PATH="%buildroot%{_libdir}"
make check %{?_smp_mflags} || (cat test-suite.log && exit 1)

%install
#this is an attempt at fixing shlib errors
export LD_LIBRARY_PATH="%buildroot%{_libdir}"
%make_install
# remove static files
find %buildroot -name "*\.la" -delete
# udev
mkdir -p %buildroot/%{_udevrulesdir}
cp debian/ola.udev %buildroot/%{_udevrulesdir}
#Java Part
cd java
%mvn_install

%files
#actual files
%doc AUTHORS NEWS README
%{_bindir}/ola*
%{_bindir}/rdmpro_sniffer
%{_bindir}/usbpro_firmware
%{_libdir}/libola*\.so\.*
%{_mandir}/man1/ola*
%{_mandir}/man1/usbpro_firmware*
%{_mandir}/man1/rdmpro_sniffer*
%{_mandir}/man1/logic_*
%{_udevrulesdir}/ola.udev
%license LICENCE COPYING

%files devel
%doc README.developer
%{_includedir}/ola**
%{_libdir}/libola*\.so
%{_libdir}/pkgconfig/*

%files -n python2-%{name}
%dir %{python2_sitelib}/ola
%{python2_sitelib}/ola/*\.py*
%{python2_sitelib}/ola/rpc

%files rdm-tests
%{_bindir}/rdm_model_collector.py*
%{_bindir}/rdm_responder_test.py*
%{_bindir}/rdm_test_server.py*
%{_mandir}/man1/rdm_*
%{_datadir}/ola/rdm-server
%{python2_sitelib}/ola/testing
#license file for jquery's js libs
%license tools/rdm/static/MIT-LICENSE.txt

%files data
%{_datadir}/olad
%dir %{_datadir}/ola
%{_datadir}/ola/pids
#license files for angular's, jquery's and bootstrap's js/css libs
%license javascript/new-src/README.md 

%files ja-rule
%{_bindir}/ja-rule
%{_bindir}/ja-rule-controller

%files java-client -f java/.mfiles
%files java-client-javadoc -f java/.mfiles-javadoc

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig

%changelog
* Sat Dec 10 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.3-1
- new version, changelog: https://github.com/OpenLightingProject/ola/releases/tag/0.10.3
- switch back to readdir_r and disable warnings of it's deprecation

* Sat Nov 19 2016 Orion Poplawski <orion@cora.nwra.com> - 0.10.2-3
- Rebuild for protobuf 3.1.0

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.2-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Sun May 22 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.2-1
- new version, changelog: https://github.com/OpenLightingProject/ola/releases/tag/0.10.2
- drop el6 and 7 support

* Wed Mar 02 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.1-2
- add patch to fix readdir_r deprecation warning

* Mon Feb 29 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.1-1
- new version 0.10.1 full changelog:
  https://github.com/OpenLightingProject/ola/releases/tag/0.10.1

* Thu Feb 25 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-9
- cleanup spec file
- build experimental java client when possible
- build experimental ja-rule tools 

* Wed Feb 24 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-8
- add patch to fix the deprication of cppunit-config in the cppunit package

* Fri Feb 05 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-7
- add patch so it gets buildt with gnu++98 instead of c++14 (which is gcc6 default)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jan 14 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-5
- obsolete old python2-ola package on epel6

* Wed Jan 13 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-4
- fix require "python(2)-ola" package in rdm-tests for epel6

* Tue Jan 12 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-3
- fix missing manpage

* Tue Jan 12 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-2
- fix naming for python package in EPEL6
- fix manpage packaging for rdm test

* Mon Jan 04 2016 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.10.0-1
- new version

* Fri Dec 11 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-8
- Fix python package in rawhide

* Thu Dec 10 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-7
- fix the license macro on el6

* Wed Dec 09 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-6
- add ldocnfig trigger to devel package
- remove buildroot usage in build
- fix license shim

* Tue Dec 08 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-5
- fix non-executable-script errors

* Tue Dec 08 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-4
- *attempt* to fix shlib errors
- fix missing-call-to-setgroups-before-setuid

* Thu Nov 12 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-3
- split off /usr/share into separate data package
- enable the removal of rpath again
- use dir directive for some directories
- don't require systemd on epel6
- remove TODO and Changelog from documents since they are not relavant

* Thu Nov 12 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-2
- Include more licence files
- cleanup files
- require systemd for udev rules
- disable the removal of rpath

* Thu Oct 1 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.8-1
- update to 0.9.8 full changelog here: https://github.com/OpenLightingProject/ola/releases/tag/0.9.8
- include patch for autotools deprication notice
- switch to pkgconfig for most buildrequires
- add licence files
- remove Changelog and TODO from doc files
- use dist tag in release tag

* Sat Sep 19 2015 Dave Olsthoorn <dave.olsthoorn@gmail.com> - 0.9.7-1
- update to 0.9.7
- OLA now requires libusb

* Thu Aug 27 2009 Kevin Deldycke <kevin@deldycke.com> 0.3.1.trunk.20090827-1mdv2009.1
- Rename all project from lla to OLA
- Upgrade to the latest OLA 0.3.1 from the master branch of the git repository
- OLA now requires libmicrohttpd, libcppunit, protobuf and libctemplate
- Disable the --no-undefined option and make all undefined symbols weakly bound
- Add check step
- Rebuild RPM for Mandriva 2009.1

* Mon May 12 2008 Kevin Deldycke <kev@coolcavemen.com> 0.2.3.200710210908-1mdv2008.1
- Ported from Fedora Core 8 ( http://rpms.netmindz.net/FC8/SRPMS.netmindz/lla-0.2.3.200710210908-1.fc8.src.rpm ) to Mandriva 2008.1

* Sun Apr 29 2007 Will Tatam <will@netmindz.net> 0.1.3-1
- First Build
